// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_FileLockInterruptionException__
#define __java_nio_channels_FileLockInterruptionException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class FileLockInterruptionException;
      }
    }
  }
}

class java::nio::channels::FileLockInterruptionException : public ::java::io::IOException
{
public:
  FileLockInterruptionException ();

  static ::java::lang::Class class$;
};

#endif /* __java_nio_channels_FileLockInterruptionException__ */
