// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_AuthenticationException__
#define __javax_naming_AuthenticationException__

#pragma interface

#include <javax/naming/NamingSecurityException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class AuthenticationException;
    }
  }
}

class javax::naming::AuthenticationException : public ::javax::naming::NamingSecurityException
{
public:
  AuthenticationException ();
  AuthenticationException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_AuthenticationException__ */
