// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_convert_Input_UTF8__
#define __gnu_gcj_convert_Input_UTF8__

#pragma interface

#include <gnu/gcj/convert/BytesToUnicode.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace convert
      {
        class Input_UTF8;
      }
    }
  }
}

class gnu::gcj::convert::Input_UTF8 : public ::gnu::gcj::convert::BytesToUnicode
{
public:
  virtual ::java::lang::String *getName ();
  virtual jint read (jcharArray, jint, jint);
  Input_UTF8 ();
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::gnu::gcj::convert::BytesToUnicode ))))  partial;
  jint partial_bytes_expected;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_convert_Input_UTF8__ */
