// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_NamingSecurityException__
#define __javax_naming_NamingSecurityException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class NamingSecurityException;
    }
  }
}

class javax::naming::NamingSecurityException : public ::javax::naming::NamingException
{
public:
  NamingSecurityException ();
  NamingSecurityException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 5855287647294685775LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_NamingSecurityException__ */
